@@ -1,6 +1,5 @@
 from abc import ABC
 from typing import Any
-from backStrategy.utils.object import BarData
 
 
 class CtaTemplate(ABC):
@@ -8,15 +7,13 @@ class CtaTemplate(ABC):
     parameters: list = []
 
     def __init__(
-        self,
-        cta_engine: Any,
-        strategy_name: str,
-        symbol: str,
-        setting: dict,
+            self,
+            cta_engine: Any,
+            strategy_name: str,
+            setting: dict,
     ) -> None:
         self.cta_engine: "CtaEngine" = cta_engine
         self.strategy_name: str = strategy_name
-        self.symbol: str = symbol
         self.inited: bool = False
         self.update_setting(setting)
 
@@ -32,9 +29,8 @@ class CtaTemplate(ABC):
     def on_start(self) -> None:
         pass
 
-    def on_bar(self, bar: BarData) -> None:
+    def on_bar(self, bar: dict) -> None:
         pass
 
     def on_stop(self):
         pass
-
